#
# spec file for package distrobox
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           distrobox
Version:        1.6.0.1
Release:        1.1
Summary:        Use any linux distribution inside your terminal
License:        GPL-3.0-only
URL:            https://github.com/89luca89/distrobox
Source:         https://github.com/89luca89/distrobox/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        distrobox.conf
# Default to distrobox-enter when just distrobox is used
Requires:       %{_bindir}/basename
Requires:       %{_bindir}/find
Requires:       %{_bindir}/grep
Requires:       %{_bindir}/sed
Requires:       (%{_bindir}/podman or %{_bindir}/docker)
# Idea would be: if bash completion is already there, let's have it. If
# not, let's "only" recommend it...
Requires:       (%{name}-bash-completion if bash-completion)
BuildRequires:  ImageMagick
BuildRequires:  hicolor-icon-theme
BuildArch:      noarch

%description
Use any Linux distribution inside your terminal.
Distrobox uses podman or docker to create containers using the Linux distribution of your choice.
The created container will be tightly integrated with the host,
allowing sharing of the HOME directory of the user, external storage,
external USB devices and graphical apps (X11/Wayland), and audio.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for distrobox.

%prep
%autosetup -p1 -n distrobox-%{version}

%build

%install
./install --prefix %{buildroot}/%{_prefix}

install -d -m0755 %{buildroot}%{_docdir}/%{name}
install -m 0644 docs/*.md %{buildroot}%{_docdir}/%{name}

%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_distconfdir}/distrobox
install -m 0644 %{SOURCE1} %{buildroot}%{_distconfdir}/distrobox/distrobox.conf
%else
mkdir -p %{buildroot}%{_sysconfdir}/distrobox
install -m 0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/distrobox/distrobox.conf
%endif

# Move the icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mv %{buildroot}%{_datadir}/icons/terminal-distrobox-icon.svg \
   %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

# Generate all the other icon sizes
for sz in 16 22 24 32 36 48 64 72 96 128 256; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps
    convert terminal-distrobox-icon.svg -resize ${sz}x${sz} \
        %{buildroot}%{_datadir}/icons/hicolor/${sz}x${sz}/apps/terminal-distrobox-icon.png
done

%files
%license COPYING.md
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_bindir}/%{name}-*
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man1/%{name}-*.1.gz
%if 0%{?suse_version} > 1500
%dir %{_distconfdir}/distrobox
%{_distconfdir}/distrobox/distrobox.conf
%else
%config %{_sysconfdir}/distrobox
%config(noreplace) %{_sysconfdir}/distrobox/distrobox.conf
%endif
%dir %{_datadir}/icons/hicolor/
%dir %{_datadir}/icons/hicolor/*x*/
%dir %{_datadir}/icons/hicolor/*x*/apps/
%{_datadir}/icons/hicolor/*/apps/terminal-distrobox-icon.png
%{_datadir}/icons/hicolor/scalable/apps/terminal-distrobox-icon.svg

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}*

%changelog
* Tue Nov 21 2023 Michal Vyskocil <michal.vyskocil@gmail.com>
- Update to version 1.6.0.1:
  * Export: fix exporting desktop app.
  * Init: fix nvidia library integration.
- Update to version 1.6.0:
  * Lilipod support
  * Improved nvidia integration, particularly for cuda
  * General improvements in the init process
  * Improve user's shell handling, so that it now always respects the chsh done inside the container
  * Fix tzdata/zoneinfo problems
  * Rootful containers now will properly setup user password for sudo
  * General polish in initful containers
  * Initful containers now support also OpenRC when present
  * Initful containers will now have also a proper systemd user session
  * New --unshare-all, --unshare-netns, --unshare-process, --unshare-devsys
    flags in create
    + Now initful + unshare-all containers can be used as playgrounds for
    services like LXC and Libvirt more easily
  * New container_additional_volumes configuration
  * Export fixes and improvements in multi-icon and space-in-name handling
  * Exported binaries will be runnable between distroboxes
  * Exported binaries will always run in a login shell
  * Assemble is now more polished and supports all of create flags
  * Assemble can now export apps/binaries directly from the manifest
* Fri Jul  7 2023 Frederic Crozat <fcrozat@suse.com>
- Update to version 1.5.0.2:
  * Fix typo in instructions for setting podman-host path
  * Fix user initialization for ubuntu 23.04
  * Compatibility: add openEULER and Linux Mint containers
  * Fix docker minimum version to 19.03.15.
  * Better container detection in host-exec
  * fix host file sync when unsharing network
- Changes from version 1.5.0.1:
  * Fix bashism in assemble.
  * Revert to using distrobox-enter for upgrade.
  * Fix bug in init_readlink with relative paths in init.
  * Improve dry-run output to show a flag for each line in enter/create.
* Sun Jun 18 2023 Enrico Belleri <kilgore.trout@idesmi.eu>
- Update to version 1.5.0:
  * additional-packages flag in create, to directly add packages during init
  * NVidia GPU Support for containers: distrobox will attempt to share host's drivers with the container
  * New distrobox-assemble command lets you declare your distroboxes-as-code, in an easy config file
  * Now, removing a distrobox will un-export apps and binaries exported by it
  * Init is now more flexible in how it adds packages, allowing for greater compatibility
  * Init now supports systemd containers using --additional-packages systemd during creation
  * General reliability improvements, lots of bug fixes and QoL
* Tue Feb 21 2023 Richard Brown <rbrown@suse.com>
- Remove container_image from .conf, obsoleted by
  container_image_default
- use official distrobox:latest container instead of vanilla
  tumbleweed to speedup start times, still call it tumbleweed
  because it is
* Tue Jan 24 2023 Predrag Ivanović <predivan@mts.rs>
- Use tubleweed:latest as the default image
  instead of, hardcoded in 'distrobox-create', fedora:toolbox.
* Wed Dec 28 2022 Ayush Kumar <ayush06feb@gmail.com>
- Update to latest version (1.4.2.1). Some changes:
  * all: fix setting up default images and names
  * compatibility: add gentoo docker image
  * compatibility: change debian 8 image
  * completion: Remove shebangs from bash completions
  * completion: add compatibility list flag, add image name
    autocompletion
  * create/enter/export: Add home prefix
  * create: Fix using --home with space in path
  * create: use --entrypoint to override entrypoint defined by
    image
  * distrobox: remove trap from the wrapper
  * docs: Add resource limitation tips
  * docs: Fix example configuration file
  * docs: Update handler function to support bash scripts
  * enter/export: handle quotes in arguments in a better way
  * enter: exclude LANG environment variables
  * enter: remove detach-keys, work on #398
  * export/enter: inject container ID at enter-time, in order to be
    used in export
  * export: fix variable declaration
  * export: look at global user services while trying to export a
    service
  * export: use realpath on icons
  * init: Add init and pre-init hook defaults as supported config
    options
  * init: add missing findmnt in OpenSUSE
  * init: better systemd unit cleanup
  * init: copy skel files only if using custom home
  * init: fix overriding of SHELL at each start, override default
    SHELL only the first time
  * init: fix sudoers spam (missing " in check)
  * init: fix void-linux package incompatibility error
  * init: fix vte installation; add --noreplace to prevent repeated
    builds
  * init: integrate with kerberos host only if it is installed on
    the host.
  * init: skip external mounts when searching for sockets
  * init: specify package for gentoo
  * init: use container's path for SHELL instead of host's one
  * init: use findmnt instead of mountpoint, fixing compatibility
    with old distributions
  * install-podman: Fix cni_plugin_dirs
  * install: do not use scraping, use fixed version
  * main: Do not open manpager automatically
  Full list available at: https://github.com/89luca89/distrobox/releases/tag/1.4.2.1
* Thu Nov 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend bash-completion subpackage: this triggers
  installation even if bash-completion is not there yet. All (well,
  most for now) packages are handled to install the completion IF
  bash-completion is present (which is the default on standard
  setups).
* Thu Sep 29 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.4.1)
- Patches removed:
  0001-distrobox-if-no-command-is-specified-default-to-ente.patch
- Add a bash-completion subpackage
- Changes in 1.4.1:
  * completion: add bash completion support!
  * create/enter: revert 52a34fb
  * create: add --no-entry
  * docs: update host and guest lists
  * docs: redundant "else" in readme
  * init: add mesa and vulkan drivers by default
  * init: don't query filesystems mounted by beesd
  * install-podman: update to 4.2.1
  * install-podman: install crun, it generally
    works better in rootless.
  * install-podman: fix default configuration
  * ephemeral: do cleanup even in case of errors
  * generate-entry: auto-discover curl or wget.
* Wed Sep 14 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.4.0)
- Patches removed:
  0001-enter-fix-automatic-container-creation-when-r-is-use.patch
  0002-distrobox-handle-situations-with-weird-manpages-setu.patch
  0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
  0003-distrobox-if-no-command-is-specified-default-to-ente.patch
  0004-opensuse-check-for-the-config-file-in-usr-etc-too.patch
- Patches added:
  0001-distrobox-if-no-command-is-specified-default-to-ente.patch
- Changes in 1.4.0:
  * New distrobox upgrade command, to update all the containers at once
  * New distrobox generate-entry command, to add your distrobox to the app list
    note that from 1.4.0 onwards this will be the default behaviour for all the
    new containers created
  * New distrobox ephemeral command, to quickly spawn, use and delete a container.
    All-in-one.
  * New install-podman script to install Podman in $HOME. Handy for @ValveSoftware
    SteamDeck users
  * Distrobox-host-exec now uses exclusively the host-spawn command from @1player
  * Better support for AD/LDap and Kerberos usernames
  * Better support for Nix/Guix hosts
  * Plenty of bug fixes and CI/Test improvements smile
* Thu Jul 28 2022 Dario Faggioli <dfaggioli@suse.com>
- Fix a (potential0 problem with man and manpages
  * Patch added:
    0002-distrobox-handle-situations-with-weird-manpages-setu.patch
- Default to distrobox-enter when only typing distrobox
  * Patch added:
    0003-distrobox-if-no-command-is-specified-default-to-ente.patch
- Reordered the patchqueue:
  * Patch removed:
    0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
  * Patch added:
    0004-opensuse-check-for-the-config-file-in-usr-etc-too.patch
* Wed Jul 27 2022 Dario Faggioli <dfaggioli@suse.com>
- enable non-interactive mode by default
- Fix a but with automatic cretion of rootful containers
  * Patch added:
    0001-enter-fix-automatic-container-creation-when-r-is-use.patch
- Rework the /usr/etc config file patch (better changelog)
  * Patch removed:
    0001-Read-config-in-usr-etc-too.patch
  * Patch added:
    0002-opensuse-check-for-the-config-file-in-usr-etc-too.patch
- Switched to %%autosetup in the spec file
* Tue Jun 21 2022 Dario Faggioli <dfaggioli@suse.com>
- Move config file in vendor specific path by default
  * Patch added:
    0001-Read-config-in-usr-etc-too.patch
- Update to latest version, 1.3.1
  * all: allow users to specify non_interactive=true/false
  * all: improve code readability and formatting, follow happy paths
  * create: make it clearer to the user the container creation output
  * create: remove check about clone and image name
  * docs: Fix typo by @rugk in #308
  * docs: remove WSL2 entry, cannot actively check if works correctly
  * enter: automatically create containers during 'distrobox-enter' (if they don't exist!)
  * export: add --root to rooful containers
  * export: fix DBusActivatable not working
  * host-exec docs: 755 -> 644
  * host-exec: change [N/y] to [y/N]
  * init: fix apt hooks to make systemd install work
  * init: move zypper recommends after the basic packages install,
    make OpenSUSE containers creation faster
  * install: add --next flag to install latest commit from git
  * stop: update misleading comment
  * uninstall: interactive rm won't work when executed throught pipe
  * docs: update compatibility list
  * Confirm support for:
    Redhat UBI 9
    Redhat UBI 9-init
    Redhat UBI 9-minimal
    AlmaLinux 8-minimal
    AlmaLinux 9-minimal
    AlmaLinux 9
* Mon May 30 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version, 1.3.0:
  * new tools and commands!
  * rootful containers support
  * new supported distros
  * improved integration with the host
  * many fixes and improvements
  For full log, see: https://github.com/89luca89/distrobox/releases/tag/1.3.0
* Sat May 14 2022 Dario Faggioli <dfaggioli@suse.com>
- Add a config file, so that we pull a tumbleweed image by default
- Update to latest version, 1.2.15. Some changes:
  * init: Allow all package manager checks to run
  * init: Fix compatibility with init containers
  * init: add pacman post-hook to neutralize systemd post-hooks in case we're not in an init-enabled container
  * init: exclude dbus system socket sharing, it doesn't work and creates confusing error messages
  * init: fix missing check before umounting on init-enabled containers
  * init: fix new archlinux mount: /usr/lib/libmount.so.1: version MOUNT_2_38 not found (required by mount) error, upgrade before installing packages
  * init: fix regression introduced in 3f014de where containers where thinking they were on a booted systemd
  * init: improve arch linux integration - add pacman pre-post hooks to reduce number of errors occurring
  * create/enter: print error messages only when not in dry-run
  * create: add work around for incompatibility between systemd/journald ACLs and overlayfs
  * enter: check for container errors during first start
  * enter: do not instantiate a tty if we do not have one
  * enter: extract container SHELL from inspect, use that as fallback if no custom command provided
  * enter: fix boolean logic on tty use
  * enter: fix unbound variable with --dry-run
  * export: hide unuseful stderr in export
* Tue Mar 29 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version 1.2.14. Some changes:
  * all: detect if running sudo and improve error messages for container managers, pointing to documentation
  * fix: move selinux fix into create phase
  * enter: escape --workdir argument
  * enter: Enter at workdir through child path of '/run/host' by @ennec-e in #186
  * stop: Add distrobox-stop command
  * enter: use container's $PATH when entering
  * create: resolve path before mounting
  * init: If user already exists in /etc/passwd set props again, do not skip
  * init: Fix grep match of very short user or group names
  * init: tighter systemd integration with host
  * init: support LDAP/AD mail usernames
  * export: support exporting of system flatpaks and document it
  Full list available at: https://github.com/89luca89/distrobox/releases/tag/1.2.14
- Switch from `install -p` to `install --prefix` (see
  https://github.com/89luca89/distrobox/pull/190)
* Fri Mar 11 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version 1.2.13
- Fix some rpmlint suggested spec file issues
* Mon Jan 31 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest version (1.2.12)
- Add licence to the spec file and fix formatting, add some globbing
- Include the manpages in the package
- Add changelog file
  * File added: distrobox.changes
* Wed Jan 12 2022 Nathan D <dhanas.nathan@gmail.com>
- Initial package
